/**
 * @fileoverview Shader attributes module.
 */
export declare type AttributeData = Float32List | Float32List[];
/**
 * Abstraction for sending data to shaders in attributes.
 */
export declare class Attribute<Data extends AttributeData> {
    protected readonly name_: string;
    protected readonly dimension_: number;
    protected data_: Data;
    protected buffer_: WebGLBuffer;
    constructor(name_: string, dimension_: number, data_: Data);
    send(gl: WebGLRenderingContext, program: WebGLProgram): void;
    length(): number;
}
declare type AttributeBuilder = (name: string, data: Float32List) => Attribute<Float32List>;
/**
 * Sends a float attribute to a shader.
 */
export declare const FloatAttribute: AttributeBuilder;
/**
 * Sends a 2-dimensional vector attribute to a shader.
 */
export declare const Vec2Attribute: AttributeBuilder;
/**
 * Sends a 3-dimensional vector attribute to a shader.
 */
export declare const Vec3Attribute: AttributeBuilder;
/**
 * Sends a 4-dimensional vector attribute to a shader.
 */
export declare const Vec4Attribute: AttributeBuilder;
declare class MatrixAttribute extends Attribute<Float32List[]> {
    constructor(name: string, dimension: number, data: Float32List[]);
    send(gl: WebGLRenderingContext, program: WebGLProgram): void;
}
declare type MatAttributeBuilder = (name: string, data: Float32List[]) => MatrixAttribute;
/**
 * Sends a 2-dimensional matrix attribute to a shader.
 */
export declare const Mat2Attribute: MatAttributeBuilder;
/**
 * Sends a 3-dimensional matrix attribute to a shader.
 */
export declare const Mat3Attribute: MatAttributeBuilder;
/**
 * Sends a 4-dimensional matrix attribute to a shader.
 */
export declare const Mat4Attribute: MatAttributeBuilder;
export {};
