/**
 * @fileoverview Module contains the function for building a Shader.
 */
import { AttributeData, Attribute } from './attributes';
import { Viewport } from './gl';
import { TextureUniform, TextureData, Uniform, UniformData } from './uniforms';
/**
 * Interface for the options you can supply to Shader.
 */
export interface ShaderOptions {
    attributes: Attribute<AttributeData>[];
    uniforms?: Uniform<UniformData>[];
    viewport?: Viewport;
    mode?: number;
    indices?: Uint16Array;
    clear?: boolean;
}
declare type RenderTarget = HTMLCanvasElement | TextureUniform<TextureData>;
declare type ShaderFunc = (target: RenderTarget) => RenderTarget;
/**
 * Create a shader function to render to a target.
 */
export declare const Shader: (vertexSrc: string, fragmentSrc: string, opts: ShaderOptions) => ShaderFunc;
export {};
